MultiValidator class

Use for multi validation operations

Inheritance

Constructors

MultiValidator({required List<SmartFormValidatorService> validators})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validators List<SmartFormValidatorService>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(String? value) String?
override

Operators

operator ==(Object other) bool
The equality operator.
inherited